Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1247)

Unified Diff: components/devtools_discovery/devtools_discovery_manager.h

Issue 2234343002: Fixes naming issues in Browser protocol handler + adds tests. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/devtools_discovery/devtools_discovery_manager.h
diff --git a/components/devtools_discovery/devtools_discovery_manager.h b/components/devtools_discovery/devtools_discovery_manager.h
index 023e067a035e7993ee9499343e765130ae8a8dd7..2e1eb06d98516985fe6ab08bce2ac1803c79ab38 100644
--- a/components/devtools_discovery/devtools_discovery_manager.h
+++ b/components/devtools_discovery/devtools_discovery_manager.h
@@ -40,8 +40,8 @@ class DevToolsDiscoveryManager {
DevToolsTargetDescriptor::List GetDescriptors();
std::unique_ptr<DevToolsTargetDescriptor> CreateNew(const GURL& url);
- // Handles Browser.newPage only.
- std::unique_ptr<base::DictionaryValue> HandleNewTargetCommand(
+ // Handles Browser.createTarget only.
+ std::unique_ptr<base::DictionaryValue> HandleCreateTargetCommand(
base::DictionaryValue* command_dict);
private:

Powered by Google App Engine
This is Rietveld 408576698